# django-sso-app

Django single sign-on app.


## Description

...


## Note

This project has been set up using PyScaffold 3.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
